/*
 * Copyright 2010-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jetbrains.kotlin.idea.refactoring.introduce;

import com.intellij.testFramework.TestDataPath;
import org.jetbrains.kotlin.test.InnerTestClasses;
import org.jetbrains.kotlin.test.JUnit3RunnerWithInners;
import org.jetbrains.kotlin.test.JetTestUtils;
import org.jetbrains.kotlin.test.TestMetadata;
import org.junit.runner.RunWith;

import java.io.File;
import java.util.regex.Pattern;

/** This class is generated by {@link org.jetbrains.kotlin.generators.tests.TestsPackage}. DO NOT MODIFY MANUALLY */
@SuppressWarnings("all")
@InnerTestClasses({
        JetExtractionTestGenerated.IntroduceVariable.class,
        JetExtractionTestGenerated.ExtractFunction.class,
        JetExtractionTestGenerated.IntroduceProperty.class,
})
@RunWith(JUnit3RunnerWithInners.class)
public class JetExtractionTestGenerated extends AbstractJetExtractionTest {
    @TestMetadata("idea/testData/refactoring/introduceVariable")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class IntroduceVariable extends AbstractJetExtractionTest {
        public void testAllFilesPresentInIntroduceVariable() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/introduceVariable"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("ArrayAccessExpr.kt")
        public void testArrayAccessExpr() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/ArrayAccessExpr.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("callUnderSmartCast.kt")
        public void testCallUnderSmartCast() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/callUnderSmartCast.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("ClassBody.kt")
        public void testClassBody() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/ClassBody.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("DoWhileAddBlock.kt")
        public void testDoWhileAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/DoWhileAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("DoWhileAddBlockInner.kt")
        public void testDoWhileAddBlockInner() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/DoWhileAddBlockInner.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("FewOccurrences.kt")
        public void testFewOccurrences() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/FewOccurrences.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("FunctionAddBlock.kt")
        public void testFunctionAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/FunctionAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("FunctionAddBlockInner.kt")
        public void testFunctionAddBlockInner() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/FunctionAddBlockInner.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("FunctionLiteral.kt")
        public void testFunctionLiteral() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/FunctionLiteral.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("FunctionLiteralFromExpected.kt")
        public void testFunctionLiteralFromExpected() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/FunctionLiteralFromExpected.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("FunctionLiteralWithExtraArgs.kt")
        public void testFunctionLiteralWithExtraArgs() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/FunctionLiteralWithExtraArgs.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("IfCondition.kt")
        public void testIfCondition() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/IfCondition.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("IfElseAddBlock.kt")
        public void testIfElseAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/IfElseAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("IfElseAddBlockInner.kt")
        public void testIfElseAddBlockInner() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/IfElseAddBlockInner.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("IfThenAddBlock.kt")
        public void testIfThenAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/IfThenAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("IfThenAddBlockInner.kt")
        public void testIfThenAddBlockInner() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/IfThenAddBlockInner.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("IfThenValuedAddBlock.kt")
        public void testIfThenValuedAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/IfThenValuedAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("It.kt")
        public void testIt() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/It.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("LoopRange.kt")
        public void testLoopRange() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/LoopRange.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("ManyInnerOccurences.kt")
        public void testManyInnerOccurences() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/ManyInnerOccurences.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("ManyOccurrences.kt")
        public void testManyOccurrences() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/ManyOccurrences.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("noConflictWithInnerVariable.kt")
        public void testNoConflictWithInnerVariable() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/noConflictWithInnerVariable.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("NoExplicitReceivers.kt")
        public void testNoExplicitReceivers() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/NoExplicitReceivers.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("NoExplicitReceiversUnresolved.kt")
        public void testNoExplicitReceiversUnresolved() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/NoExplicitReceiversUnresolved.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("NoNewLinesInBetween.kt")
        public void testNoNewLinesInBetween() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/NoNewLinesInBetween.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("NoNewLinesInBetweenNoBraces.kt")
        public void testNoNewLinesInBetweenNoBraces() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/NoNewLinesInBetweenNoBraces.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("nonEquivalentReceivers.kt")
        public void testNonEquivalentReceivers() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/nonEquivalentReceivers.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("notNullAssertion.kt")
        public void testNotNullAssertion() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/notNullAssertion.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("OccurrencesInStringTemplate.kt")
        public void testOccurrencesInStringTemplate() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/OccurrencesInStringTemplate.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("OneExplicitReceiver.kt")
        public void testOneExplicitReceiver() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/OneExplicitReceiver.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("PropertyAccessorAddBlock.kt")
        public void testPropertyAccessorAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/PropertyAccessorAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("PropertyAccessorAddBlockInner.kt")
        public void testPropertyAccessorAddBlockInner() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/PropertyAccessorAddBlockInner.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("ReplaceOccurence.kt")
        public void testReplaceOccurence() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/ReplaceOccurence.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("Simple.kt")
        public void testSimple() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/Simple.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("SimpleCreateValue.kt")
        public void testSimpleCreateValue() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/SimpleCreateValue.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("StringInjection.kt")
        public void testStringInjection() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/StringInjection.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("TwoExplicitReceivers.kt")
        public void testTwoExplicitReceivers() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/TwoExplicitReceivers.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("TypeElement.kt")
        public void testTypeElement() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/TypeElement.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("UnresolvedOccurrences.kt")
        public void testUnresolvedOccurrences() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/UnresolvedOccurrences.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("WhenAddBlock.kt")
        public void testWhenAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/WhenAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("WhenAddBlockInner.kt")
        public void testWhenAddBlockInner() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/WhenAddBlockInner.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("WhenParts.kt")
        public void testWhenParts() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/WhenParts.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("WhenValuedAddBlock.kt")
        public void testWhenValuedAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/WhenValuedAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("WhileAddBlock.kt")
        public void testWhileAddBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/WhileAddBlock.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("WhileAddBlockInner.kt")
        public void testWhileAddBlockInner() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/WhileAddBlockInner.kt");
            doIntroduceVariableTest(fileName);
        }

        @TestMetadata("WhileCondition.kt")
        public void testWhileCondition() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceVariable/WhileCondition.kt");
            doIntroduceVariableTest(fileName);
        }
    }

    @TestMetadata("idea/testData/refactoring/extractFunction")
    @TestDataPath("$PROJECT_ROOT")
    @InnerTestClasses({
            ExtractFunction.Basic.class,
            ExtractFunction.ControlFlow.class,
            ExtractFunction.DefaultContainer.class,
            ExtractFunction.Delegation.class,
            ExtractFunction.Duplicates.class,
            ExtractFunction.Initializers.class,
            ExtractFunction.Parameters.class,
            ExtractFunction.TypeParameters.class,
    })
    @RunWith(JUnit3RunnerWithInners.class)
    public static class ExtractFunction extends AbstractJetExtractionTest {
        public void testAllFilesPresentInExtractFunction() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("idea/testData/refactoring/extractFunction/basic")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Basic extends AbstractJetExtractionTest {
            public void testAllFilesPresentInBasic() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/basic"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("delegatingFunction.kt")
            public void testDelegatingFunction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/delegatingFunction.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("extensionFunForArray.kt")
            public void testExtensionFunForArray() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/extensionFunForArray.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("fakeOverride.kt")
            public void testFakeOverride() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/fakeOverride.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("fragmentWithComment.kt")
            public void testFragmentWithComment() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/fragmentWithComment.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("fragmentWithMultilineComment.kt")
            public void testFragmentWithMultilineComment() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/fragmentWithMultilineComment.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("invisibleType.kt")
            public void testInvisibleType() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/invisibleType.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localClassExtraction.kt")
            public void testLocalClassExtraction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localClassExtraction.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localClassFunctionRef.kt")
            public void testLocalClassFunctionRef() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localClassFunctionRef.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localClassPropertyRef.kt")
            public void testLocalClassPropertyRef() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localClassPropertyRef.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localExtraction.kt")
            public void testLocalExtraction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localExtraction.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localFunExtraction.kt")
            public void testLocalFunExtraction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localFunExtraction.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localFunctionInTheMiddleSimpleControlFlow.kt")
            public void testLocalFunctionInTheMiddleSimpleControlFlow() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localFunctionInTheMiddleSimpleControlFlow.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localFunctionInTheMiddleUnusedVar.kt")
            public void testLocalFunctionInTheMiddleUnusedVar() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localFunctionInTheMiddleUnusedVar.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localFunctionInTheMiddleUsedVar.kt")
            public void testLocalFunctionInTheMiddleUsedVar() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localFunctionInTheMiddleUsedVar.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localFunctionRef.kt")
            public void testLocalFunctionRef() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localFunctionRef.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localObjectRef.kt")
            public void testLocalObjectRef() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/localObjectRef.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("malformedExpression.kt")
            public void testMalformedExpression() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/malformedExpression.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("malformedStatements.kt")
            public void testMalformedStatements() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/malformedStatements.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("misdirectedRef.kt")
            public void testMisdirectedRef() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/misdirectedRef.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("noConflictWithInnerFunction.kt")
            public void testNoConflictWithInnerFunction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/noConflictWithInnerFunction.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("privateMemberInClassObject.kt")
            public void testPrivateMemberInClassObject() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/privateMemberInClassObject.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("privateMemberRef.kt")
            public void testPrivateMemberRef() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/privateMemberRef.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("privateNestedClass.kt")
            public void testPrivateNestedClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/privateNestedClass.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("privateSetter.kt")
            public void testPrivateSetter() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/privateSetter.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("refInReturn.kt")
            public void testRefInReturn() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/refInReturn.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("traitFunction.kt")
            public void testTraitFunction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/basic/traitFunction.kt");
                doExtractFunctionTest(fileName);
            }
        }

        @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow")
        @TestDataPath("$PROJECT_ROOT")
        @InnerTestClasses({
                ControlFlow.ConditionalJumps.class,
                ControlFlow.Default.class,
                ControlFlow.DefiniteReturns.class,
                ControlFlow.EvaluateExpression.class,
                ControlFlow.ExitPointEquivalence.class,
                ControlFlow.Initializer.class,
                ControlFlow.OutputValues.class,
                ControlFlow.Throws.class,
                ControlFlow.Unextractable.class,
        })
        @RunWith(JUnit3RunnerWithInners.class)
        public static class ControlFlow extends AbstractJetExtractionTest {
            public void testAllFilesPresentInControlFlow() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class ConditionalJumps extends AbstractJetExtractionTest {
                public void testAllFilesPresentInConditionalJumps() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("conditionalBreakWithIf.kt")
                public void testConditionalBreakWithIf() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/conditionalBreakWithIf.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("conditionalBreakWithIfAndExtraVars.kt")
                public void testConditionalBreakWithIfAndExtraVars() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/conditionalBreakWithIfAndExtraVars.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("conditionalBreakWithIfElse.kt")
                public void testConditionalBreakWithIfElse() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/conditionalBreakWithIfElse.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("conditionalBreakWithWhen.kt")
                public void testConditionalBreakWithWhen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/conditionalBreakWithWhen.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("conditionalReturnWithIf.kt")
                public void testConditionalReturnWithIf() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/conditionalReturnWithIf.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("conditionalReturnWithIfElse.kt")
                public void testConditionalReturnWithIfElse() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/conditionalReturnWithIfElse.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("conditionalReturnWithWhen.kt")
                public void testConditionalReturnWithWhen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/conditionalReturnWithWhen.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("unconditionalBreakWithIf.kt")
                public void testUnconditionalBreakWithIf() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/unconditionalBreakWithIf.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("unconditionalBreakWithIfElse.kt")
                public void testUnconditionalBreakWithIfElse() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/unconditionalBreakWithIfElse.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("unconditionalBreakWithWhen.kt")
                public void testUnconditionalBreakWithWhen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/conditionalJumps/unconditionalBreakWithWhen.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/default")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Default extends AbstractJetExtractionTest {
                public void testAllFilesPresentInDefault() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/default"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("defaultCF.kt")
                public void testDefaultCF() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/default/defaultCF.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("defaultCFWithExtraVars.kt")
                public void testDefaultCFWithExtraVars() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/default/defaultCFWithExtraVars.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("defaultCFWithJumps.kt")
                public void testDefaultCFWithJumps() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/default/defaultCFWithJumps.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("ignoredReturnValueWithIf.kt")
                public void testIgnoredReturnValueWithIf() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/default/ignoredReturnValueWithIf.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("ignoredReturnValueWithIfNoBlocks.kt")
                public void testIgnoredReturnValueWithIfNoBlocks() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/default/ignoredReturnValueWithIfNoBlocks.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("ignoredReturnValueWithWhen.kt")
                public void testIgnoredReturnValueWithWhen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/default/ignoredReturnValueWithWhen.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("ignoredReturnValueWithWhenNoBlocks.kt")
                public void testIgnoredReturnValueWithWhenNoBlocks() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/default/ignoredReturnValueWithWhenNoBlocks.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/definiteReturns")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class DefiniteReturns extends AbstractJetExtractionTest {
                public void testAllFilesPresentInDefiniteReturns() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/definiteReturns"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("definiteReturnWithIf.kt")
                public void testDefiniteReturnWithIf() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/definiteReturns/definiteReturnWithIf.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("definiteReturnWithWhen.kt")
                public void testDefiniteReturnWithWhen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/definiteReturns/definiteReturnWithWhen.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("singleDefiniteReturn.kt")
                public void testSingleDefiniteReturn() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/definiteReturns/singleDefiniteReturn.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class EvaluateExpression extends AbstractJetExtractionTest {
                public void testAllFilesPresentInEvaluateExpression() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("evalExprInIfCondition.kt")
                public void testEvalExprInIfCondition() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalExprInIfCondition.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalExprInIfElse.kt")
                public void testEvalExprInIfElse() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalExprInIfElse.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalExprInIfThen.kt")
                public void testEvalExprInIfThen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalExprInIfThen.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalExprInWhenBranch.kt")
                public void testEvalExprInWhenBranch() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalExprInWhenBranch.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalExprInWhenCondition.kt")
                public void testEvalExprInWhenCondition() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalExprInWhenCondition.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalExprInWhenSubject.kt")
                public void testEvalExprInWhenSubject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalExprInWhenSubject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalExpressionBodyFunction.kt")
                public void testEvalExpressionBodyFunction() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalExpressionBodyFunction.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalIfExpr.kt")
                public void testEvalIfExpr() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalIfExpr.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalWhenExpr.kt")
                public void testEvalWhenExpr() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/evalWhenExpr.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("simpleEvalExpr.kt")
                public void testSimpleEvalExpr() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/simpleEvalExpr.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("trailingLambdaEmptyArgList.kt")
                public void testTrailingLambdaEmptyArgList() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/trailingLambdaEmptyArgList.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("trailingLambdaNoArgList.kt")
                public void testTrailingLambdaNoArgList() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/trailingLambdaNoArgList.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("trailingLambdaNonEmptyArgList.kt")
                public void testTrailingLambdaNonEmptyArgList() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/trailingLambdaNonEmptyArgList.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("trailingLambdaNonEmptyArgListWithNamedArgs.kt")
                public void testTrailingLambdaNonEmptyArgListWithNamedArgs() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/evaluateExpression/trailingLambdaNonEmptyArgListWithNamedArgs.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class ExitPointEquivalence extends AbstractJetExtractionTest {
                public void testAllFilesPresentInExitPointEquivalence() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("breakAndReturn.kt")
                public void testBreakAndReturn() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence/breakAndReturn.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("breakContinueAndDefault.kt")
                public void testBreakContinueAndDefault() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence/breakContinueAndDefault.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("continueAndReturn.kt")
                public void testContinueAndReturn() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence/continueAndReturn.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("defaultAndBreak.kt")
                public void testDefaultAndBreak() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence/defaultAndBreak.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("defaultAndContinue.kt")
                public void testDefaultAndContinue() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence/defaultAndContinue.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("defaultAndReturn.kt")
                public void testDefaultAndReturn() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence/defaultAndReturn.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("defaultAndReturnInWhen.kt")
                public void testDefaultAndReturnInWhen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence/defaultAndReturnInWhen.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("multipleBreaks.kt")
                public void testMultipleBreaks() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/exitPointEquivalence/multipleBreaks.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/initializer")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Initializer extends AbstractJetExtractionTest {
                public void testAllFilesPresentInInitializer() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/initializer"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("propertyWithInitializer.kt")
                public void testPropertyWithInitializer() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/initializer/propertyWithInitializer.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("propertyWithInitializerAndExtraVars.kt")
                public void testPropertyWithInitializerAndExtraVars() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/initializer/propertyWithInitializerAndExtraVars.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("propertyWithInitializerAndUnusedVars.kt")
                public void testPropertyWithInitializerAndUnusedVars() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/initializer/propertyWithInitializerAndUnusedVars.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("propertyWithSeparateInitializer.kt")
                public void testPropertyWithSeparateInitializer() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/initializer/propertyWithSeparateInitializer.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("valueUsedInAnonymousObject.kt")
                public void testValueUsedInAnonymousObject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/initializer/valueUsedInAnonymousObject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("valueUsedInLambda.kt")
                public void testValueUsedInLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/initializer/valueUsedInLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("valueUsedInLocalFunction.kt")
                public void testValueUsedInLocalFunction() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/initializer/valueUsedInLocalFunction.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class OutputValues extends AbstractJetExtractionTest {
                public void testAllFilesPresentInOutputValues() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/outputValues"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("genericPair.kt")
                public void testGenericPair() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/genericPair.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("initializersAndUpdate.kt")
                public void testInitializersAndUpdate() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/initializersAndUpdate.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("nestedNonInlinableCall.kt")
                public void testNestedNonInlinableCall() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/nestedNonInlinableCall.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("outputValueWithExpression.kt")
                public void testOutputValueWithExpression() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/outputValueWithExpression.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("outputValueWithReturn.kt")
                public void testOutputValueWithReturn() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/outputValueWithReturn.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("outputValueWithSingleLineExpression.kt")
                public void testOutputValueWithSingleLineExpression() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/outputValueWithSingleLineExpression.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("outputValuesWithExpression.kt")
                public void testOutputValuesWithExpression() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/outputValuesWithExpression.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("pair.kt")
                public void testPair() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/pair.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("pairOfInitalizersWithNonLocalUsages.kt")
                public void testPairOfInitalizersWithNonLocalUsages() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/pairOfInitalizersWithNonLocalUsages.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("pairOfVarInitalizersWithNonLocalUsages.kt")
                public void testPairOfVarInitalizersWithNonLocalUsages() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/pairOfVarInitalizersWithNonLocalUsages.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("pairWithIf.kt")
                public void testPairWithIf() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/pairWithIf.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("pairWithNameClash.kt")
                public void testPairWithNameClash() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/pairWithNameClash.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("pairWithWhen.kt")
                public void testPairWithWhen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/pairWithWhen.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("singleOutputValue.kt")
                public void testSingleOutputValue() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/singleOutputValue.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("singleOutputValueWithIf.kt")
                public void testSingleOutputValueWithIf() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/singleOutputValueWithIf.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("singleOutputValueWithIfElse.kt")
                public void testSingleOutputValueWithIfElse() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/singleOutputValueWithIfElse.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("singleOutputValueWithWhen.kt")
                public void testSingleOutputValueWithWhen() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/singleOutputValueWithWhen.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("singleOutputValueWithWhenElse.kt")
                public void testSingleOutputValueWithWhenElse() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/singleOutputValueWithWhenElse.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("tooManyOutputValues.kt")
                public void testTooManyOutputValues() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/tooManyOutputValues.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("tooManyOutputValuesAsList.kt")
                public void testTooManyOutputValuesAsList() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/tooManyOutputValuesAsList.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("triple.kt")
                public void testTriple() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/triple.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("usedAndUnusedOutputValues.kt")
                public void testUsedAndUnusedOutputValues() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/usedAndUnusedOutputValues.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("valAndVarInitalizersWithNonLocalUsages.kt")
                public void testValAndVarInitalizersWithNonLocalUsages() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/valAndVarInitalizersWithNonLocalUsages.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("valuesUsedInLambdaOnly.kt")
                public void testValuesUsedInLambdaOnly() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/valuesUsedInLambdaOnly.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("valuesUsedInNestedBlock.kt")
                public void testValuesUsedInNestedBlock() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/outputValues/valuesUsedInNestedBlock.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/throws")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Throws extends AbstractJetExtractionTest {
                public void testAllFilesPresentInThrows() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/throws"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("breakWithThrow.kt")
                public void testBreakWithThrow() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/throws/breakWithThrow.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("continueWithThrow.kt")
                public void testContinueWithThrow() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/throws/continueWithThrow.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalExpressionWithThrow.kt")
                public void testEvalExpressionWithThrow() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/throws/evalExpressionWithThrow.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("nonValuedReturnWithThrow.kt")
                public void testNonValuedReturnWithThrow() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/throws/nonValuedReturnWithThrow.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("outputValueWithThrow.kt")
                public void testOutputValueWithThrow() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/throws/outputValueWithThrow.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("returnWithThrow.kt")
                public void testReturnWithThrow() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/throws/returnWithThrow.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/controlFlow/unextractable")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Unextractable extends AbstractJetExtractionTest {
                public void testAllFilesPresentInUnextractable() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/controlFlow/unextractable"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("anonymousObject.kt")
                public void testAnonymousObject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/unextractable/anonymousObject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("evalExpressionWithReturn.kt")
                public void testEvalExpressionWithReturn() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/unextractable/evalExpressionWithReturn.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("jumpsAndReturns.kt")
                public void testJumpsAndReturns() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/unextractable/jumpsAndReturns.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("multipleJumps.kt")
                public void testMultipleJumps() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/unextractable/multipleJumps.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("multipleReturnsWithDefault.kt")
                public void testMultipleReturnsWithDefault() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/unextractable/multipleReturnsWithDefault.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("variablesOutOfScope.kt")
                public void testVariablesOutOfScope() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/controlFlow/unextractable/variablesOutOfScope.kt");
                    doExtractFunctionTest(fileName);
                }
            }
        }

        @TestMetadata("idea/testData/refactoring/extractFunction/defaultContainer")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class DefaultContainer extends AbstractJetExtractionTest {
            public void testAllFilesPresentInDefaultContainer() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/defaultContainer"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("anonymousObject.kt")
            public void testAnonymousObject() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/defaultContainer/anonymousObject.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("classFunction.kt")
            public void testClassFunction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/defaultContainer/classFunction.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("lambda.kt")
            public void testLambda() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/defaultContainer/lambda.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localClass.kt")
            public void testLocalClass() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/defaultContainer/localClass.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localFunction.kt")
            public void testLocalFunction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/defaultContainer/localFunction.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("nestedLambda.kt")
            public void testNestedLambda() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/defaultContainer/nestedLambda.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("topLevelFunction.kt")
            public void testTopLevelFunction() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/defaultContainer/topLevelFunction.kt");
                doExtractFunctionTest(fileName);
            }
        }

        @TestMetadata("idea/testData/refactoring/extractFunction/delegation")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Delegation extends AbstractJetExtractionTest {
            public void testAllFilesPresentInDelegation() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/delegation"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("delegationByExpression.kt")
            public void testDelegationByExpression() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/delegation/delegationByExpression.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("delegationByExpressionFull.kt")
            public void testDelegationByExpressionFull() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/delegation/delegationByExpressionFull.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("delegationBySuperCall.kt")
            public void testDelegationBySuperCall() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/delegation/delegationBySuperCall.kt");
                doExtractFunctionTest(fileName);
            }
        }

        @TestMetadata("idea/testData/refactoring/extractFunction/duplicates")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Duplicates extends AbstractJetExtractionTest {
            public void testAllFilesPresentInDuplicates() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/duplicates"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("branchingMatch1.kt")
            public void testBranchingMatch1() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/branchingMatch1.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("branchingMatch2.kt")
            public void testBranchingMatch2() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/branchingMatch2.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("defaultCF.kt")
            public void testDefaultCF() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/defaultCF.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("insertAfterDuplicates.kt")
            public void testInsertAfterDuplicates() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/insertAfterDuplicates.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("insertBeforeDuplicates.kt")
            public void testInsertBeforeDuplicates() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/insertBeforeDuplicates.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("multipleOutputValuesMatching.kt")
            public void testMultipleOutputValuesMatching() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/multipleOutputValuesMatching.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("nestedStrongMatch.kt")
            public void testNestedStrongMatch() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/nestedStrongMatch.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("notNullAssertion.kt")
            public void testNotNullAssertion() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/notNullAssertion.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("outputValueAndUnitMatching.kt")
            public void testOutputValueAndUnitMatching() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/outputValueAndUnitMatching.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("outputValueMatching.kt")
            public void testOutputValueMatching() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/outputValueMatching.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("singleExpression.kt")
            public void testSingleExpression() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/duplicates/singleExpression.kt");
                doExtractFunctionTest(fileName);
            }
        }

        @TestMetadata("idea/testData/refactoring/extractFunction/initializers")
        @TestDataPath("$PROJECT_ROOT")
        @InnerTestClasses({
                Initializers.Accessors.class,
                Initializers.Classes.class,
                Initializers.Functions.class,
                Initializers.Properties.class,
        })
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Initializers extends AbstractJetExtractionTest {
            public void testAllFilesPresentInInitializers() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/initializers"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/initializers/accessors")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Accessors extends AbstractJetExtractionTest {
                public void testAllFilesPresentInAccessors() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/initializers/accessors"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("memberProperty.kt")
                public void testMemberProperty() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/accessors/memberProperty.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("memberPropertyWithLambda.kt")
                public void testMemberPropertyWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/accessors/memberPropertyWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("topLevelProperty.kt")
                public void testTopLevelProperty() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/accessors/topLevelProperty.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("topLevelPropertyWithLambda.kt")
                public void testTopLevelPropertyWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/accessors/topLevelPropertyWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/initializers/classes")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Classes extends AbstractJetExtractionTest {
                public void testAllFilesPresentInClasses() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/initializers/classes"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("classInitializer.kt")
                public void testClassInitializer() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/classes/classInitializer.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("classInitializerWithLambda.kt")
                public void testClassInitializerWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/classes/classInitializerWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("classParameters.kt")
                public void testClassParameters() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/classes/classParameters.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("classParametersWithLambda.kt")
                public void testClassParametersWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/classes/classParametersWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/initializers/functions")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Functions extends AbstractJetExtractionTest {
                public void testAllFilesPresentInFunctions() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/initializers/functions"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("localFunction.kt")
                public void testLocalFunction() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/localFunction.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("localFunctionParameters.kt")
                public void testLocalFunctionParameters() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/localFunctionParameters.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("localFunctionParametersWithLambda.kt")
                public void testLocalFunctionParametersWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/localFunctionParametersWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("localFunctionWithLambda.kt")
                public void testLocalFunctionWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/localFunctionWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("memberFunction.kt")
                public void testMemberFunction() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/memberFunction.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("memberFunctionParameters.kt")
                public void testMemberFunctionParameters() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/memberFunctionParameters.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("memberFunctionParametersWithLambda.kt")
                public void testMemberFunctionParametersWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/memberFunctionParametersWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("memberFunctionWithLambda.kt")
                public void testMemberFunctionWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/memberFunctionWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("topLevelFunction.kt")
                public void testTopLevelFunction() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/topLevelFunction.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("topLevelFunctionParameters.kt")
                public void testTopLevelFunctionParameters() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/topLevelFunctionParameters.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("topLevelFunctionParametersWithLambda.kt")
                public void testTopLevelFunctionParametersWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/topLevelFunctionParametersWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("topLevelFunctionWithLambda.kt")
                public void testTopLevelFunctionWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/functions/topLevelFunctionWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/initializers/properties")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Properties extends AbstractJetExtractionTest {
                public void testAllFilesPresentInProperties() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/initializers/properties"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("localProperty.kt")
                public void testLocalProperty() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/properties/localProperty.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("localPropertyWithLambda.kt")
                public void testLocalPropertyWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/properties/localPropertyWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("memberProperty.kt")
                public void testMemberProperty() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/properties/memberProperty.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("memberPropertyWithLambda.kt")
                public void testMemberPropertyWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/properties/memberPropertyWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("multiDeclaration.kt")
                public void testMultiDeclaration() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/properties/multiDeclaration.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("nestedInMultiDeclaration.kt")
                public void testNestedInMultiDeclaration() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/properties/nestedInMultiDeclaration.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("topLevelProperty.kt")
                public void testTopLevelProperty() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/properties/topLevelProperty.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("topLevelPropertyWithLambda.kt")
                public void testTopLevelPropertyWithLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/initializers/properties/topLevelPropertyWithLambda.kt");
                    doExtractFunctionTest(fileName);
                }
            }
        }

        @TestMetadata("idea/testData/refactoring/extractFunction/parameters")
        @TestDataPath("$PROJECT_ROOT")
        @InnerTestClasses({
                Parameters.CandidateTypes.class,
                Parameters.ExtractSuper.class,
                Parameters.ExtractThis.class,
                Parameters.It.class,
                Parameters.Misc.class,
                Parameters.NonDenotableTypes.class,
        })
        @RunWith(JUnit3RunnerWithInners.class)
        public static class Parameters extends AbstractJetExtractionTest {
            public void testAllFilesPresentInParameters() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/parameters"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class CandidateTypes extends AbstractJetExtractionTest {
                public void testAllFilesPresentInCandidateTypes() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/parameters/candidateTypes"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("cantLiftAnonymousToSupertype.kt")
                public void testCantLiftAnonymousToSupertype() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/cantLiftAnonymousToSupertype.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("flexibleTypesWithNull.kt")
                public void testFlexibleTypesWithNull() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/flexibleTypesWithNull.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("flexibleTypesWithoutNull.kt")
                public void testFlexibleTypesWithoutNull() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/flexibleTypesWithoutNull.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("liftAnonymousToSupertype1.kt")
                public void testLiftAnonymousToSupertype1() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/liftAnonymousToSupertype1.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("liftAnonymousToSupertype2.kt")
                public void testLiftAnonymousToSupertype2() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/liftAnonymousToSupertype2.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("nonNullableTypes.kt")
                public void testNonNullableTypes() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/nonNullableTypes.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("nullableTypes.kt")
                public void testNullableTypes() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/nullableTypes.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("typeHierarchy1.kt")
                public void testTypeHierarchy1() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/typeHierarchy1.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("typeHierarchy2.kt")
                public void testTypeHierarchy2() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/typeHierarchy2.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("typeHierarchy3.kt")
                public void testTypeHierarchy3() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/typeHierarchy3.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("typeHierarchy4.kt")
                public void testTypeHierarchy4() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/candidateTypes/typeHierarchy4.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/parameters/extractSuper")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class ExtractSuper extends AbstractJetExtractionTest {
                public void testAllFilesPresentInExtractSuper() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/parameters/extractSuper"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("labeledSuperPropertyCall.kt")
                public void testLabeledSuperPropertyCall() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractSuper/labeledSuperPropertyCall.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("superFunctionCall.kt")
                public void testSuperFunctionCall() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractSuper/superFunctionCall.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("superLabeledFunctionCall.kt")
                public void testSuperLabeledFunctionCall() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractSuper/superLabeledFunctionCall.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("superPropertyCall.kt")
                public void testSuperPropertyCall() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractSuper/superPropertyCall.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class ExtractThis extends AbstractJetExtractionTest {
                public void testAllFilesPresentInExtractThis() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/parameters/extractThis"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("explicitLabeledThisInMember.kt")
                public void testExplicitLabeledThisInMember() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis/explicitLabeledThisInMember.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("explicitThisInExtension.kt")
                public void testExplicitThisInExtension() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis/explicitThisInExtension.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("explicitThisInMember.kt")
                public void testExplicitThisInMember() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis/explicitThisInMember.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("implicitAndExplicitLabeledThisInMember.kt")
                public void testImplicitAndExplicitLabeledThisInMember() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis/implicitAndExplicitLabeledThisInMember.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("implicitAndExplicitThisInExtension.kt")
                public void testImplicitAndExplicitThisInExtension() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis/implicitAndExplicitThisInExtension.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("implicitThisInExtension.kt")
                public void testImplicitThisInExtension() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis/implicitThisInExtension.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("implicitThisInMember.kt")
                public void testImplicitThisInMember() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis/implicitThisInMember.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedThisAsArgument.kt")
                public void testQualifiedThisAsArgument() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/extractThis/qualifiedThisAsArgument.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/parameters/it")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class It extends AbstractJetExtractionTest {
                public void testAllFilesPresentInIt() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/parameters/it"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("innerIt.kt")
                public void testInnerIt() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/it/innerIt.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("lambdaWithIt.kt")
                public void testLambdaWithIt() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/it/lambdaWithIt.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("outerIt.kt")
                public void testOuterIt() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/it/outerIt.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("simpleIt.kt")
                public void testSimpleIt() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/it/simpleIt.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/parameters/misc")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class Misc extends AbstractJetExtractionTest {
                public void testAllFilesPresentInMisc() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/parameters/misc"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("classObject.kt")
                public void testClassObject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/classObject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("extensionLambda.kt")
                public void testExtensionLambda() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/extensionLambda.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("extensionLambdaAsParameter.kt")
                public void testExtensionLambdaAsParameter() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/extensionLambdaAsParameter.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("innerClassObject.kt")
                public void testInnerClassObject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/innerClassObject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("kt5001.kt")
                public void testKt5001() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/kt5001.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("multiDeclaration.kt")
                public void testMultiDeclaration() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/multiDeclaration.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("multipleOccurrences.kt")
                public void testMultipleOccurrences() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/multipleOccurrences.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("namedArguments.kt")
                public void testNamedArguments() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/namedArguments.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedAnnotation.kt")
                public void testQualifiedAnnotation() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/qualifiedAnnotation.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedClassObject.kt")
                public void testQualifiedClassObject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/qualifiedClassObject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedEnum.kt")
                public void testQualifiedEnum() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/qualifiedEnum.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedObject.kt")
                public void testQualifiedObject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/qualifiedObject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedPackage.kt")
                public void testQualifiedPackage() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/qualifiedPackage.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedTypeArg.kt")
                public void testQualifiedTypeArg() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/qualifiedTypeArg.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedTypeInValueArg.kt")
                public void testQualifiedTypeInValueArg() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/qualifiedTypeInValueArg.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("qualifiedTypeRef.kt")
                public void testQualifiedTypeRef() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/qualifiedTypeRef.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("reducedParameterList.kt")
                public void testReducedParameterList() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/reducedParameterList.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("thisInObject.kt")
                public void testThisInObject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/thisInObject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("typeRef.kt")
                public void testTypeRef() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/typeRef.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("usagesInCallArgs.kt")
                public void testUsagesInCallArgs() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/usagesInCallArgs.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("variableAsFunction.kt")
                public void testVariableAsFunction() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/misc/variableAsFunction.kt");
                    doExtractFunctionTest(fileName);
                }
            }

            @TestMetadata("idea/testData/refactoring/extractFunction/parameters/nonDenotableTypes")
            @TestDataPath("$PROJECT_ROOT")
            @RunWith(JUnit3RunnerWithInners.class)
            public static class NonDenotableTypes extends AbstractJetExtractionTest {
                public void testAllFilesPresentInNonDenotableTypes() throws Exception {
                    JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/parameters/nonDenotableTypes"), Pattern.compile("^(.+)\\.kt$"), true);
                }

                @TestMetadata("anonymousObject.kt")
                public void testAnonymousObject() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/nonDenotableTypes/anonymousObject.kt");
                    doExtractFunctionTest(fileName);
                }

                @TestMetadata("localClass.kt")
                public void testLocalClass() throws Exception {
                    String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/parameters/nonDenotableTypes/localClass.kt");
                    doExtractFunctionTest(fileName);
                }
            }
        }

        @TestMetadata("idea/testData/refactoring/extractFunction/typeParameters")
        @TestDataPath("$PROJECT_ROOT")
        @RunWith(JUnit3RunnerWithInners.class)
        public static class TypeParameters extends AbstractJetExtractionTest {
            public void testAllFilesPresentInTypeParameters() throws Exception {
                JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/extractFunction/typeParameters"), Pattern.compile("^(.+)\\.kt$"), true);
            }

            @TestMetadata("localClassInBound.kt")
            public void testLocalClassInBound() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/localClassInBound.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("localClassInTypeConstraint.kt")
            public void testLocalClassInTypeConstraint() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/localClassInTypeConstraint.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("simpleTypeParameter.kt")
            public void testSimpleTypeParameter() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/simpleTypeParameter.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("simpleTypeParameterWithConstraint.kt")
            public void testSimpleTypeParameterWithConstraint() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/simpleTypeParameterWithConstraint.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("typeParamInArgument.kt")
            public void testTypeParamInArgument() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/typeParamInArgument.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("typeParametersAndConstraintsCombined1.kt")
            public void testTypeParametersAndConstraintsCombined1() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/typeParametersAndConstraintsCombined1.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("typeParametersAndConstraintsCombined2.kt")
            public void testTypeParametersAndConstraintsCombined2() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/typeParametersAndConstraintsCombined2.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("typeParametersAndConstraintsCombined3.kt")
            public void testTypeParametersAndConstraintsCombined3() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/typeParametersAndConstraintsCombined3.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("typeParametersCombined1.kt")
            public void testTypeParametersCombined1() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/typeParametersCombined1.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("typeParametersCombined2.kt")
            public void testTypeParametersCombined2() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/typeParametersCombined2.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("typeParametersCombined3.kt")
            public void testTypeParametersCombined3() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/typeParametersCombined3.kt");
                doExtractFunctionTest(fileName);
            }

            @TestMetadata("typeParametersCombinedAndThis.kt")
            public void testTypeParametersCombinedAndThis() throws Exception {
                String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/extractFunction/typeParameters/typeParametersCombinedAndThis.kt");
                doExtractFunctionTest(fileName);
            }
        }
    }

    @TestMetadata("idea/testData/refactoring/introduceProperty")
    @TestDataPath("$PROJECT_ROOT")
    @RunWith(JUnit3RunnerWithInners.class)
    public static class IntroduceProperty extends AbstractJetExtractionTest {
        public void testAllFilesPresentInIntroduceProperty() throws Exception {
            JetTestUtils.assertAllTestsPresentByMetadata(this.getClass(), new File("idea/testData/refactoring/introduceProperty"), Pattern.compile("^(.+)\\.kt$"), true);
        }

        @TestMetadata("extractFromDefaultValueInConstructor.kt")
        public void testExtractFromDefaultValueInConstructor() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractFromDefaultValueInConstructor.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractFromDefaultValueInFun.kt")
        public void testExtractFromDefaultValueInFun() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractFromDefaultValueInFun.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractLazyMultipleExpressions.kt")
        public void testExtractLazyMultipleExpressions() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractLazyMultipleExpressions.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractLazyToClass.kt")
        public void testExtractLazyToClass() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractLazyToClass.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractLazyToFile.kt")
        public void testExtractLazyToFile() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractLazyToFile.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractLazyToTrait.kt")
        public void testExtractLazyToTrait() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractLazyToTrait.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractLazyWithBlock.kt")
        public void testExtractLazyWithBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractLazyWithBlock.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractLazyWithCallSiteReturn.kt")
        public void testExtractLazyWithCallSiteReturn() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractLazyWithCallSiteReturn.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractToClassWithNameClash.kt")
        public void testExtractToClassWithNameClash() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractToClassWithNameClash.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractToClassWithNameClashAndAnonymousInitializer.kt")
        public void testExtractToClassWithNameClashAndAnonymousInitializer() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractToClassWithNameClashAndAnonymousInitializer.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractToFileWithNameClash.kt")
        public void testExtractToFileWithNameClash() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractToFileWithNameClash.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractToFunction.kt")
        public void testExtractToFunction() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractToFunction.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractUnit.kt")
        public void testExtractUnit() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractUnit.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithGetterMultipleExpressions.kt")
        public void testExtractWithGetterMultipleExpressions() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithGetterMultipleExpressions.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithGetterToClass.kt")
        public void testExtractWithGetterToClass() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithGetterToClass.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithGetterToFile.kt")
        public void testExtractWithGetterToFile() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithGetterToFile.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithGetterToTrait.kt")
        public void testExtractWithGetterToTrait() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithGetterToTrait.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithInitializerAndBlock.kt")
        public void testExtractWithInitializerAndBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithInitializerAndBlock.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithInitializerAndCallSiteReturn.kt")
        public void testExtractWithInitializerAndCallSiteReturn() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithInitializerAndCallSiteReturn.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithInitializerAndSingleElementBlock.kt")
        public void testExtractWithInitializerAndSingleElementBlock() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithInitializerAndSingleElementBlock.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithInitializerMultipleExpressions.kt")
        public void testExtractWithInitializerMultipleExpressions() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithInitializerMultipleExpressions.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithInitializerToClass.kt")
        public void testExtractWithInitializerToClass() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithInitializerToClass.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithInitializerToFile.kt")
        public void testExtractWithInitializerToFile() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithInitializerToFile.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithInitializerToTrait.kt")
        public void testExtractWithInitializerToTrait() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithInitializerToTrait.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("extractWithParams.kt")
        public void testExtractWithParams() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/extractWithParams.kt");
            doIntroducePropertyTest(fileName);
        }

        @TestMetadata("replaceDuplicates.kt")
        public void testReplaceDuplicates() throws Exception {
            String fileName = JetTestUtils.navigationMetadata("idea/testData/refactoring/introduceProperty/replaceDuplicates.kt");
            doIntroducePropertyTest(fileName);
        }
    }
}
